smirnov-package: Provides two taxonomic coefficients from E. S. Smirnov "Taxonomic analysis" (1969) book
Description
This tiny package contains one function smirnov() which calculates two scaled taxonomic coefficients, Txy (coefficient of similarity) and Txx (coefficient of originality). These two characteristics may be used for the analysis of similarities between any number of taxonomic groups, and also for assessing uniqueness of giving taxon. It is possible to use smirnov() output as a distance measure: convert it to distance by "as.dist(1 - smirnov(x))"
Arguments
Details
ll{
Package: smirnov
Type: Package
Version: 1.0
Date: 2010-10-25
License: What license is it under?
LazyLoad: yes
}
The input of smirnov() is any binary matrix (i.e., presence-absence matrix). The output is a matrix where diagonal is filled with Txx coefficients and other cells with Txy coefficients.
References
Smirnov E. S. 1969. Taxonomical analysis. Moscow, Moscow University Publishers. [in Russian].
# Simple example from p. 44 of Smirnov's book:s1 <- c(1,0,1,0,0,1,1,0,0)
s2 <- c(1,0,0,1,1,0,0,1,0)
s3 <- c(0,1,1,0,1,0,0,0,1)
smirnov(rbind(s1, s2, s3))